@@ -23,29 +23,29 @@
 #' information on the calibration and assignment in the appendix of Courtiol et
 #' al. 2019.
 #'
-#' \enumerate{ \item Fitting the isoscape model with [isofit]:
+#' \enumerate{ \item Fitting the isoscape model with [`isofit`]:
 #'
-#' The function [isofit] fits a geostatistical model, which
+#' The function [`isofit`] fits a geostatistical model, which
 #' approximates the relationship between the topographic features of a location
-#' and its isotopic signature (see [isofit] for details). The model
+#' and its isotopic signature (see [`isofit`] for details). The model
 #' fits observations of isotopic delta values at several geographic locations
 #' (hereafter, called \emph{sources}). One common type of sources used in
 #' ecology is the delta values for hydrogen in precipitation water collected at
 #' weather stations, but one may also use measurements performed on sedentary
 #' organisms. In either case, the accuracy of the isoscape (and thereby the
 #' accuracy of assignments) increases with the number and spatial coverage of
-#' the sources. The function [isofit] is designed to fit the model
+#' the sources. The function [`isofit`] is designed to fit the model
 #' on data aggregated per location across all measurements. If instead you want
 #' to fit the model on measurements split per time intervals (e.g. per month),
 #' within each location, you should use the alternative function
-#' [isomultifit]. Either way the data must be prepared using the
-#' function [prepsources].
+#' [`isomultifit`]. Either way the data must be prepared using the
+#' function [`prepsources`].
 #'
-#' \item Preparing the structural raster with [prepraster]:
+#' \item Preparing the structural raster with [`prepraster`]:
 #'
 #' Building isoscapes and assigning organisms to their origin requires an
 #' adequate structural raster, i.e. a matrix representing a spatial grid. The
-#' function [prepraster] allows restricting the extent of the raster
+#' function [`prepraster`] allows restricting the extent of the raster
 #' to the area covered by isoscape data (in order to avoid extrapolation) and to
 #' reduce the resolution of the original structural raster (in order to speed up
 #' computation in all following steps). Note that aggregating the raster may
@@ -54,30 +54,30 @@
 #' changes depending on the aggregation function, which in turn will affect
 #' model predictions.
 #'
-#' We provide the function [getelev] to download an elevation raster
+#' We provide the function [`getelev`] to download an elevation raster
 #' for the entire world at a resolution of one altitude per square-km, and other
 #' rasters may be used. Such an elevation raster can be used as a structural
 #' raster. We have also stored a low resolution raster for Germany in our
-#' package (see [ElevRasterDE]) for users to try things out, but we
+#' package (see [`ElevRasterDE`]) for users to try things out, but we
 #' do not encourage its use for real application.
 #'
 #' \item Predicting the isoscape across the area covered by the elevation raster
-#' with [isoscape]:
+#' with [`isoscape`]:
 #'
-#' The function [isoscape] generates the isoscapes: it uses the
+#' The function [`isoscape`] generates the isoscapes: it uses the
 #' fitted geostatistical models to predict the isotopic values (and several
 #' variances associated to those) for each raster cell defined by the structural
-#' raster. If the model has been fitted with [isomultifit], you
-#' should use the alternative function [isomultiscape] to generate
+#' raster. If the model has been fitted with [`isomultifit`], you
+#' should use the alternative function [`isomultiscape`] to generate
 #' the isoscape.
 #'
 #' Our package allows the production of fine-tuned isoscape figures (using the
-#' function [plot.ISOSCAPE]). Alternatively, the isoscape rasters
+#' function [`plot.ISOSCAPE`]). Alternatively, the isoscape rasters
 #' can be exported as ascii raster and edited in any Geographic Information
-#' System (GIS) software (see [isoscape] and the online
+#' System (GIS) software (see [`isoscape`] and the online
 #' documentation for details).
 #'
-#' \item Fitting the calibration model with [calibfit]:
+#' \item Fitting the calibration model with [`calibfit`]:
 #'
 #' In most cases, organisms are of another kind than the sources used to build
 #' the isoscape (i.e. the isoscape is built on precipitation isotopic values and
@@ -86,27 +86,26 @@
 #' their distinct physiology and do not directly correspond to the isotopic
 #' signature of the sources. In this situation, one must use sedentary organisms
 #' to study the relationship between the isotopic values in organisms and that
-#' of their environment. The function [calibfit] fits a statistical
+#' of their environment. The function [`calibfit`] fits a statistical
 #' model on such a calibration dataset.
 #'
 #' If the isoscape is directly built from isotopic values of organisms, there is
 #' no need to fit a calibration model.
 #'
-#' \item Inferring spatial origins of samples with [isofind]:
+#' \item Inferring spatial origins of samples with [`isofind`]:
 #'
-#' The function [isofind] tests for each location across the
+#' The function [`isofind`] tests for each location across the
 #' isoscape if it presents a similar isotopic signature than the unknown origin
 #' of a given individual(s). This assignment procedure considered the some (but
 #' not all, see Courtiol et al. 2019) uncertainty stemming from the model fits
 #' (geostatistical models and calibration model). The function
-#' [plot.ISOFIND] then draws such assignment by plotting the most
+#' [`plot.ISOFIND`] then draws such assignment by plotting the most
 #' likely origin with the prediction region around it. When several organisms
 #' are being assigned, both assignments at the level of each sample and a single
 #' assignment for the whole group can be performed. }
 #'
 #' @name IsoriX-package
 #' @aliases IsoriX-package IsoriX
-#' @docType package
 #' @note Please note that the geographic coordinates (latitude,
 #' longitude) of any spatial data (locations, rasters) must be given in decimal
 #' degrees following the WGS84 spheroid standard.
@@ -118,7 +117,7 @@
 #'
 #' Stephanie Kramer-Schadt \email{kramer@@izw-berlin.de}
 #' @references Courtiol A, Rousset F, Rohwäder M, Soto DX, Lehnert L, Voigt CC, Hobson KA,
-#' Wassenaar LI, Kramer-Schadt S (2019). "Isoscape computation and inference of
+#' Wassenaar LI & Kramer-Schadt S (2019). "Isoscape computation and inference of
 #' spatial origins with mixed models using the R package IsoriX." In Hobson KA,
 #' Wassenaar LI (eds.), Tracking Animal Migration with Stable Isotopes, second
 #' edition. Academic Press, London.
@@ -128,4 +127,4 @@
 #'
 #' @keywords package
 #'
-NULL
+"_PACKAGE"
