@@ -34,7 +34,7 @@
 #'   simulated organisms. This list must contain three parameters: the
 #'   intercept, the slope, and the residual variance.
 #'
-#' @param isoscape The output of the function [isoscape]
+#' @param isoscape The output of the function [`isoscape`]
 #'
 #' @param coordinates An optional *data.frame* with columns `site_ID`,
 #' `long` and `lat`
@@ -53,11 +53,11 @@
 #' @return This functions returns a *data.frame* (see example for column
 #'   names)
 #'
-#' @seealso [calibfit] for a calibration based on simulated data
+#' @seealso [`calibfit`] for a calibration based on simulated data
 #'
-#'   [isofind] for an assignment based on simulated data
+#'   [`isofind`] for an assignment based on simulated data
 #'
-#'   [IsoriX] for the complete work-flow of our package
+#'   [`IsoriX`] for the complete work-flow of our package
 #' @keywords simulate simulation
 #' @examples
 #'
@@ -123,8 +123,8 @@ create_aliens <- function(calib_fn = list(intercept = 3, slope = 0.5, resid_var
 
   ## Choose location for the aliens
   if (length(coordinates) == 1 && is.na(coordinates)) {
-    LocationData <- data.frame(site_ID = sample(1:terra::ncell(isoscape$isoscape$mean), n_sites, replace = FALSE))
-    xy <- terra::xyFromCell(isoscape$isoscape$mean, LocationData$site_ID)
+    LocationData <- data.frame(site_ID = sample(1:terra::ncell(isoscape$isoscapes$mean), n_sites, replace = FALSE))
+    xy <- terra::xyFromCell(isoscape$isoscapes$mean, LocationData$site_ID)
     LocationData$long <- xy[, "x"]
     LocationData$lat <- xy[, "y"]
   } else {
